require_relative '../lib/image_builder/provisioners/chef_client.rb'

describe ImageBuilder::Provisioners::Chef::Client do
  before(:each) do
    @obj = ImageBuilder::Provisioners::Chef::Client.new
  end

  it 'has the expected default attributes' do
    expect(@obj.prevent_sudo).to be false
    expect(@obj.skip_install).to be false
    expect(@obj.skip_clean_client).to be false
    expect(@obj.skip_clean_node).to be false
  end

  it 'loads the expected parameters from a file as a class method' do
    # @obj.from_file(::File.join(::File.dirname(__FILE__), 'fixtures', 'test-knife.rb'))
    obj = ImageBuilder::Provisioners::Chef::Client.from_file(::File.join(::File.dirname(__FILE__), 'fixtures', 'test-knife.rb'))

    expect(obj.validation_client_name).to eql 'chef-validator'
    expect(obj.validation_key_path).to eql '/dev/null'
    expect(obj.server_url).to eql 'https://chef.chefserver.com/'
    expect(obj.encrypted_data_bag_secret_path).to eql ENV['ENCRYPTED_DATA_BAG_SECRET']
  end

  it 'has the correct packer type' do
    expect(@obj.type).to eql 'chef-client'
  end

  it 'implements packer_hash()' do
    expect(@obj.respond_to? :packer_hash).to be true
  end

  it 'behaves correctly when no chef version given' do
    expect(@obj.packer_hash.key? :install_command).to be false
    expect(@obj.packer_hash[:install_command]).to be_nil
  end

  it 'honors setting a chef version for install' do
    version = '11.16'
    @obj.chef_version = version
    expect(@obj.packer_hash.key? :install_command).to be true
    expect(@obj.packer_hash[:install_command]).to match(/\s+-v\s+#{version}/)
    expect(@obj.install_command).to match(/\s+-v\s+#{version}/)
  end
end
