require_relative '../lib/image_builder/provisioners/chef_solo.rb'

describe ImageBuilder::Provisioners::Chef::Solo do
  before(:each) do
    @obj = ImageBuilder::Provisioners::Chef::Solo.new
  end

  it 'has the expected default attributes' do
    expect(@obj.prevent_sudo).to be false
    expect(@obj.skip_install).to be false
  end

  it 'loads the expected parameters from a file as a class method' do
    # @obj.from_file(::File.join(::File.dirname(__FILE__), 'fixtures', 'test-knife.rb'))
    obj = ImageBuilder::Provisioners::Chef::Solo.from_file(::File.join(::File.dirname(__FILE__), 'fixtures', 'test-knife.rb'))

    expect(obj.encrypted_data_bag_secret_path).to eql ENV['ENCRYPTED_DATA_BAG_SECRET']
    expect(obj.cookbook_paths).to_not be_empty
  end

  it 'has the correct packer type' do
    expect(@obj.type).to eql 'chef-solo'
  end

  it 'implements packer_hash()' do
    expect(@obj.respond_to? :packer_hash).to be true
  end

  it 'behaves correctly when no chef version given' do
    expect(@obj.packer_hash.key? :install_command).to be false
    expect(@obj.packer_hash[:install_command]).to be_nil
  end

  it 'honors setting a chef version for install' do
    version = '11.14'
    @obj.chef_version = version
    expect(@obj.packer_hash.key? :install_command).to be true
    expect(@obj.packer_hash[:install_command]).to match(/\s+-v\s+#{version}/)
    expect(@obj.install_command).to match(/\s+-v\s+#{version}/)
  end
end
